OC.L10N.register(
    "activity",
    {
    "Activity" : "فعالیت",
    "Personal activity feed for %s" : "فعالیت شخصی فید برای %s",
    "Your feed URL is invalid" : "URL شما نامعتبر است",
    "Your settings have been updated." : "تنظیمات شما به روز رسانی شد",
    "Mail" : "ایمیل",
    "Stream" : "پخش",
    "Activities" : "فعالیت‌ها",
    "Error loading activities" : "خطا در بارگزاری فعالیت‌ها",
    "No activities" : "هیچ فعالیتی",
    ", " : "رشته های ترجمه نشده",
    "There are no events for this filter" : "هیچ رخدادی برای این فیلتر وجود ندارد",
    "Today" : "امروز",
    "Yesterday" : "دیروز",
    "\"remote user\"" : "\"کاربران از راه‌ دور\"",
    "Activity notification" : "هشدارهای فعالیت",
    "All Activities" : "تمام فعالیت ها",
    "Activities by you" : "فعالیت های مربوط به شما",
    "Activities by others" : "فعالیت های انجام شده توسط دیگران",
    "%s and %s" : "%s و %s",
    "Hello %s," : "سلام %s",
    "You are receiving this email because the following things happened at %s" : "شما به علت رویداد موارد زیر این ایمیل را دریافت کرده‌اید %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* و %n بیشتر"],
    "List your own actions in the stream" : "اعمال شخصی تان در پخش را لیست کنید",
    "Notify about your own actions via email" : "اطلاع رسانی درباره اعمال شخصی تان با ایمیل",
    "You need to set up your email address before you can receive notification emails." : "قبل از دریافت ایمیل های هشدار می بایست ادرس ایمیل خود را تنظیم کنید",
    "Send emails:" : "ارسال ایمیل ها:",
    "Hourly" : "ساعتی",
    "Daily" : "روزانه",
    "Weekly" : "هفتهگی",
    "Activity feed" : "فید فعالیت",
    "Enable RSS feed" : "فعالسازی فید RSS",
    "No activity yet" : "هنوز فعالیتی انجام نشده",
    "No more events to load" : "رویداد دیگری برای بارگزاری وجود ندارد",
    "Files" : "فایل ها"
},
"nplurals=1; plural=0;");
